canonical_process_source

Function canonical_process_source 

pub fn canonical_process_source(
    process: &ProcessDecl,
) -> Result<String, CanonicalSourceError>
Pretty-print one process definition as a focused source fragment.

The returned fragment is the process declaration itself. It may reference type declarations, host constructors, resources, or other processes that are only self-contained in the full module source.